==> freemedforms-project_0.7.1.orig.tar.gz: freemedforms-0.7.1/global_resources/translations/calendar_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Calendar::CalendarNavbar</name>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="157"/>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="421"/>
        <source>View range</source>
        <translation>Voir les bornes</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="386"/>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="388"/>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="390"/>
        <source>d MMM yyyy</source>
        <translation>d MMM yyyy</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="388"/>
        <source>d MMM</source>
        <translation>d MMM</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="390"/>
        <source>d</source>
        <translation>d</translation>
    </message>
</context>
<context>
    <name>Calendar::DayRangeBody</name>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="749"/>
        <source>modify</source>
        <translation>modifier</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="751"/>
        <source>remove</source>
        <translation>retirer</translation>
    </message>
</context>
<context>
    <name>Calendar::DayRangeHeader</name>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="323"/>
        <source>modify</source>
        <translation>modifier</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="325"/>
        <source>remove</source>
        <translation>retirer</translation>
    </message>
</context>
<context>
    <name>Calendar::DayWidget</name>
    <message>
        <location filename="../../libs/calendar/day_widget.cpp" line="69"/>
        <source>(untitled)</source>
        <translation>(sans titre)</translation>
    </message>
</context>
<context>
    <name>Calendar::HourRangeWidget</name>
    <message>
        <location filename="../../libs/calendar/hour_range_widget.cpp" line="90"/>
        <source>(untitled)</source>
        <translation>(sans titre)</translation>
    </message>
</context>
<context>
    <name>Calendar::Internal::BasicItemEditionDialog</name>
    <message>
        <location filename="../../libs/calendar/basic_item_edition_dialog.ui" line="14"/>
        <source>Calendar item editor</source>
        <translation>Editeur de rendez-vous</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/basic_item_edition_dialog.ui" line="45"/>
        <source>Appointment editor</source>
        <translation>Éditeur de rendez-vous</translation>
    </message>
</context>
<context>
    <name>Calendar::Internal::ItemEditorWidget</name>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="20"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="46"/>
        <source>Date, time and label</source>
        <translation>Jour, heure et libellé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="73"/>
        <source>Start</source>
        <translation>Démarre</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="98"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="139"/>
        <source>End</source>
        <translation>Fini</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="158"/>
        <source>show as busy</source>
        <translation>Montrer occupé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="229"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="282"/>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="289"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="311"/>
        <source>is private</source>
        <translation>Est privé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="325"/>
        <source>Extra</source>
        <translation>Extra</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="338"/>
        <source>General information</source>
        <translation>Informations générales</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="344"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="354"/>
        <source>Location</source>
        <translation>Localisation</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="364"/>
        <source>Calendar</source>
        <translation>Calendrier</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="385"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="394"/>
        <source>Extended description</source>
        <translation>Description étendue</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="412"/>
        <source>Full information</source>
        <translation>Information complète</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="447"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="467"/>
        <source>Select icon</source>
        <translation>Sélectionner une icône</translation>
    </message>
</context>
<context>
    <name>Calendar::MonthBody</name>
    <message>
        <location filename="../../libs/calendar/month_view.cpp" line="113"/>
        <source>d MMM</source>
        <translation>d MMM</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/month_view.cpp" line="115"/>
        <source>d</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Calendar::MonthDayWidget</name>
    <message>
        <location filename="../../libs/calendar/month_day_widget.cpp" line="88"/>
        <source>see others</source>
        <translation>voir les autres</translation>
    </message>
</context>
</TS>

==> freemedforms-project_0.7.6.orig.tar.gz: freemedforms-0.7.6/global_resources/translations/calendar_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr_FR">
<context>
    <name>Calendar::CalendarNavbar</name>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="157"/>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="427"/>
        <source>View range</source>
        <translation>Voir les bornes</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="387"/>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="388"/>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="392"/>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="396"/>
        <source>d MMM yyyy</source>
        <translation>d MMM yyyy</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="391"/>
        <source>d MMM</source>
        <translation>d MMM</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/calendar_navbar.cpp" line="395"/>
        <source>d</source>
        <translation>d</translation>
    </message>
</context>
<context>
    <name>Calendar::DayRangeBody</name>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="749"/>
        <source>modify</source>
        <translation>modifier</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="751"/>
        <source>remove</source>
        <translation>retirer</translation>
    </message>
</context>
<context>
    <name>Calendar::DayRangeHeader</name>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="226"/>
        <source>dddd d/M</source>
        <comment>short date format in agenda&apos;s calendar header</comment>
        <translation>dddd d/M</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="228"/>
        <source>ddd d/M</source>
        <comment>short date format in agenda&apos;s calendar header</comment>
        <translation>ddd d/M</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="323"/>
        <source>modify</source>
        <translation>modifier</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/day_range_view.cpp" line="325"/>
        <source>remove</source>
        <translation>retirer</translation>
    </message>
</context>
<context>
    <name>Calendar::DayWidget</name>
    <message>
        <location filename="../../libs/calendar/day_widget.cpp" line="69"/>
        <source>(untitled)</source>
        <translation>(sans titre)</translation>
    </message>
</context>
<context>
    <name>Calendar::HourRangeWidget</name>
    <message>
        <location filename="../../libs/calendar/hour_range_widget.cpp" line="90"/>
        <source>(untitled)</source>
        <translation>(sans titre)</translation>
    </message>
</context>
<context>
    <name>Calendar::Internal::BasicItemEditionDialog</name>
    <message>
        <location filename="../../libs/calendar/basic_item_edition_dialog.ui" line="14"/>
        <source>Calendar item editor</source>
        <translation>Editeur de rendez-vous</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/basic_item_edition_dialog.ui" line="45"/>
        <source>Appointment editor</source>
        <translation>Éditeur de rendez-vous</translation>
    </message>
</context>
<context>
    <name>Calendar::Internal::ItemEditorWidget</name>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="20"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="46"/>
        <source>Date, time and label</source>
        <translation>Jour, heure et libellé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="73"/>
        <source>Start</source>
        <translation>Démarre</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="98"/>
        <source>Duration</source>
        <translation>Durée</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="139"/>
        <source>End</source>
        <translation>Fini</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="158"/>
        <source>show as busy</source>
        <translation>Montrer occupé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="229"/>
        <source>Password</source>
        <translation>Mot de passe</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="282"/>
        <source>Label</source>
        <translation>Libellé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="289"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="311"/>
        <source>is private</source>
        <translation>Est privé</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="325"/>
        <source>Extra</source>
        <translation>Extra</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="338"/>
        <source>General information</source>
        <translation>Informations générales</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="344"/>
        <source>Type</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="354"/>
        <source>Location</source>
        <translation>Localisation</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="364"/>
        <source>Calendar</source>
        <translation>Calendrier</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="385"/>
        <source>Description</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="394"/>
        <source>Extended description</source>
        <translation>Description étendue</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="412"/>
        <source>Full information</source>
        <translation>Information complète</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="447"/>
        <source>Icon</source>
        <translation>Icône</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/item_editor_widget.ui" line="467"/>
        <source>Select icon</source>
        <translation>Sélectionner une icône</translation>
    </message>
</context>
<context>
    <name>Calendar::MonthBody</name>
    <message>
        <location filename="../../libs/calendar/month_view.cpp" line="113"/>
        <source>d MMM</source>
        <translation>d MMM</translation>
    </message>
    <message>
        <location filename="../../libs/calendar/month_view.cpp" line="115"/>
        <source>d</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Calendar::MonthDayWidget</name>
    <message>
        <location filename="../../libs/calendar/month_day_widget.cpp" line="88"/>
        <source>see others</source>
        <translation>voir les autres</translation>
    </message>
</context>
</TS>
